utils

package
v0.0.0-...-5275bdc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2025 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CopyDir

func CopyDir(src, dst string) error

func CopyFile

func CopyFile(src, dst string, mode os.FileMode) error

func CopyFileOrDir

func CopyFileOrDir(src, dst string) error

func ExpandPath

func ExpandPath(path string) string

func MoveFileOrDir

func MoveFileOrDir(src, dst string) error

func MoveToTrash

func MoveToTrash(path string) error

MoveToTrash moves a file or directory to the system trash

func ParseSourceAndDestination

func ParseSourceAndDestination(args []string) (string, string, error)

ParseSourceAndDestination parses the command arguments to extract source and destination.

Types

This section is empty.

Jump to